@@ -26,6 +26,6 @@ if 1>0:
     print("Creating Project Folders!!!!")
     create_project()
     current_directory = os.getcwd()
-    shutil.copyfile(r'test_environment.py', os.path.join(current_directory, 'test_environment.py'))
+    shutil.copyfile(r'test_environment.py', os.path.join(current_directory,))
 else:
     print("Something went worng!!!!")
\ No newline at end of file
